@@ -1,16 +1,20 @@
 #pragma once
 
+#include "location.hh"
 #include <cstddef>
 #include <iostream>
-#include "location.hh"
 #include <memory>
 #include <rumur/Expr.h>
 #include <rumur/Node.h>
 #include <rumur/Ptr.h>
 
+#ifndef RUMUR_API_WITH_RTTI
+#define RUMUR_API_WITH_RTTI __attribute__((visibility("default")))
+#endif
+
 namespace rumur {
 
-struct Property : public Node {
+struct RUMUR_API_WITH_RTTI Property : public Node {
 
   enum Category {
     ASSERTION,
@@ -22,8 +26,7 @@ struct Property : public Node {
   Category category;
   Ptr<Expr> expr;
 
-  Property(Category category_, const Ptr<Expr> &expr_,
-    const location &loc_);
+  Property(Category category_, const Ptr<Expr> &expr_, const location &loc_);
   Property *clone() const final;
   virtual ~Property() = default;
 
@@ -31,4 +34,4 @@ struct Property : public Node {
   void visit(ConstBaseTraversal &visitor) const final;
 };
 
-}
+} // namespace rumur
