@@ -1,18 +1,17 @@
-#include <cassert>
-#include <cstddef>
+#include "../../common/help.h"
 #include "check.h"
 #include "compares_complex_values.h"
-#include <cstdlib>
-#include <fstream>
 #include "generate_c.h"
 #include "generate_h.h"
-#include <getopt.h>
-#include "../../common/help.h"
-#include <iostream>
-#include <memory>
-#include "name_rules.h"
 #include "options.h"
 #include "resources.h"
+#include <cassert>
+#include <cstddef>
+#include <cstdlib>
+#include <fstream>
+#include <getopt.h>
+#include <iostream>
+#include <memory>
 #include <rumur/rumur.h>
 #include <sstream>
 #include <string>
@@ -22,8 +21,8 @@
 #include <vector>
 
 // a pair of input streams
-using dup_t = std::pair<std::shared_ptr<std::istream>,
-                        std::shared_ptr<std::istream>>;
+using dup_t =
+    std::pair<std::shared_ptr<std::istream>, std::shared_ptr<std::istream>>;
 
 static std::string in_filename = "<stdin>";
 static dup_t in;
@@ -36,13 +35,15 @@ static void parse_args(int argc, char **argv) {
 
   for (;;) {
     static struct option options[] = {
-      { "header",     no_argument,       0, 128 },
-      { "help",       no_argument,       0, 'h' },
-      { "output",     required_argument, 0, 'o' },
-      { "source",     no_argument,       0, 129 },
-      { "value-type", required_argument, 0, 130 },
-      { "version",    no_argument,       0, 131 },
-      { 0, 0, 0, 0 },
+        // clang-format off
+        { "header",     no_argument,       0, 128 },
+        { "help",       no_argument,       0, 'h' },
+        { "output",     required_argument, 0, 'o' },
+        { "source",     no_argument,       0, 129 },
+        { "value-type", required_argument, 0, 130 },
+        { "version",    no_argument,       0, 131 },
+        { 0, 0, 0, 0 },
+        // clang-format on
     };
 
     int option_index = 0;
@@ -53,57 +54,58 @@ static void parse_args(int argc, char **argv) {
 
     switch (c) {
 
-      case '?':
-        std::cerr << "run `" << argv[0] << " --help` to see available options\n";
-        exit(EXIT_SUCCESS);
+    case '?':
+      std::cerr << "run `" << argv[0] << " --help` to see available options\n";
+      exit(EXIT_SUCCESS);
 
-      case 128: // --header
-        source = false;
-        break;
+    case 128: // --header
+      source = false;
+      break;
 
-      case 'h': // --help
-        help(doc_murphi2c_1, doc_murphi2c_1_len);
-        exit(EXIT_SUCCESS);
+    case 'h': // --help
+      help(doc_murphi2c_1, doc_murphi2c_1_len);
+      exit(EXIT_SUCCESS);
 
-      case 'o': {
-        auto o = std::make_shared<std::ofstream>(optarg);
-        if (!o->is_open()) {
-          std::cerr << "failed to open " << optarg << "\n";
-          exit(EXIT_FAILURE);
-        }
-        out = o;
-        break;
-      }
-
-      case 129: // --source
-        source = true;
-        break;
-
-      case 130: // --value-type
-        // note that we just assume the type the user gave us exists
-        value_type = optarg;
-        break;
-
-      case 131: // --version
-        std::cout << "Murphi2C version " << rumur::get_version() << "\n";
-        exit(EXIT_SUCCESS);
-
-      default:
-        std::cerr << "unexpected error\n";
+    case 'o': {
+      auto o = std::make_shared<std::ofstream>(optarg);
+      if (!o->is_open()) {
+        std::cerr << "failed to open " << optarg << "\n";
         exit(EXIT_FAILURE);
+      }
+      out = o;
+      break;
+    }
 
+    case 129: // --source
+      source = true;
+      break;
+
+    case 130: // --value-type
+      // note that we just assume the type the user gave us exists
+      value_type = optarg;
+      break;
+
+    case 131: // --version
+      std::cout << "Murphi2C version " << rumur::get_version() << "\n";
+      exit(EXIT_SUCCESS);
+
+    default:
+      std::cerr << "unexpected error\n";
+      exit(EXIT_FAILURE);
     }
   }
 
   if (optind == argc - 1) {
     struct stat buf;
     if (stat(argv[optind], &buf) < 0) {
-      std::cerr << "failed to open " << argv[optind] << ": " << strerror(errno) << "\n";
+      std::cerr << "failed to open " << argv[optind] << ": " << strerror(errno)
+                << "\n";
       exit(EXIT_FAILURE);
     }
 
     if (S_ISDIR(buf.st_mode)) {
-      std::cerr << "failed to open " << argv[optind] << ": this is a directory\n";
+      std::cerr << "failed to open " << argv[optind]
+                << ": this is a directory\n";
       exit(EXIT_FAILURE);
     }
 
@@ -169,7 +171,7 @@ int main(int argc, char **argv) {
     return EXIT_FAILURE;
 
   // name any rules that are unnamed, so they get valid C symbols
-  name_rules(*m);
+  rumur::sanitise_rule_names(*m);
 
   // Determine if we have any == or != involving records or arrays, in which
   // case we will need to pack structs. See generate_c() for why.
