@@ -1,17 +1,17 @@
+#include "../../common/help.h"
+#include "XMLPrinter.h"
+#include "resources.h"
 #include <cassert>
 #include <cstdlib>
 #include <fstream>
 #include <getopt.h>
-#include "../../common/help.h"
 #include <iostream>
 #include <memory>
-#include "resources.h"
 #include <rumur/rumur.h>
 #include <sstream>
 #include <string>
 #include <sys/stat.h>
 #include <unistd.h>
-#include "XMLPrinter.h"
 
 static std::string in_filename = "<stdin>";
 static std::shared_ptr<std::istream> in;
@@ -19,7 +19,7 @@ static std::shared_ptr<std::istream> in_replay;
 static std::shared_ptr<std::ostream> out;
 
 // buffer the contents of stdin so we can read it twice
-static void buffer_stdin(void) {
+static void buffer_stdin() {
 
   // read in all of stdin
   std::ostringstream buf;
@@ -35,10 +35,10 @@ static void parse_args(int argc, char **argv) {
 
   for (;;) {
     static struct option options[] = {
-      { "help", no_argument, 0, '?' },
-      { "output", required_argument, 0, 'o' },
-      { "version", no_argument, 0, 128 },
-      { 0, 0, 0, 0 },
+        {"help", no_argument, 0, '?'},
+        {"output", required_argument, 0, 'o'},
+        {"version", no_argument, 0, 128},
+        {0, 0, 0, 0},
     };
 
     int option_index = 0;
@@ -49,40 +49,41 @@ static void parse_args(int argc, char **argv) {
 
     switch (c) {
 
-      case '?':
-        help(doc_murphi2xml_1, doc_murphi2xml_1_len);
-        exit(EXIT_SUCCESS);
+    case '?':
+      help(doc_murphi2xml_1, doc_murphi2xml_1_len);
+      exit(EXIT_SUCCESS);
 
-      case 'o': {
-        auto o = std::make_shared<std::ofstream>(optarg);
-        if (!o->is_open()) {
-          std::cerr << "failed to open " << optarg << "\n";
-          exit(EXIT_FAILURE);
-        }
-        out = o;
-        break;
-      }
-
-      case 128: // --version
-        std::cout << "Rumur version " << rumur::get_version() << "\n";
-        exit(EXIT_SUCCESS);
-
-      default:
-        std::cerr << "unexpected error\n";
+    case 'o': {
+      auto o = std::make_shared<std::ofstream>(optarg);
+      if (!o->is_open()) {
+        std::cerr << "failed to open " << optarg << "\n";
         exit(EXIT_FAILURE);
+      }
+      out = o;
+      break;
+    }
 
+    case 128: // --version
+      std::cout << "Rumur version " << rumur::get_version() << "\n";
+      exit(EXIT_SUCCESS);
+
+    default:
+      std::cerr << "unexpected error\n";
+      exit(EXIT_FAILURE);
     }
   }
 
   if (optind == argc - 1) {
     struct stat buf;
     if (stat(argv[optind], &buf) < 0) {
-      std::cerr << "failed to open " << argv[optind] << ": " << strerror(errno) << "\n";
+      std::cerr << "failed to open " << argv[optind] << ": " << strerror(errno)
+                << "\n";
       exit(EXIT_FAILURE);
     }
 
     if (S_ISDIR(buf.st_mode)) {
-      std::cerr << "failed to open " << argv[optind] << ": this is a directory\n";
+      std::cerr << "failed to open " << argv[optind]
+                << ": this is a directory\n";
       exit(EXIT_FAILURE);
     }
 
