@@ -1,4 +1,4 @@
 #pragma once
 
 // get a pointer to the environ variable
-char **get_environ(void);
+char **get_environ();
