@@ -12,4 +12,4 @@ std::string translate(const rumur::Expr &expr);
 // name-mangle a symbol to make it a safe SMT variable
 std::string mangle(const std::string &s, size_t id);
 
-}
+} // namespace smt
